@@ -14,7 +14,7 @@
 
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
